summaryrefslogtreecommitdiffstats
path: root/kpresenter/KPrObject.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpresenter/KPrObject.h')
-rw-r--r--kpresenter/KPrObject.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kpresenter/KPrObject.h b/kpresenter/KPrObject.h
index 598373ea..7b39be50 100644
--- a/kpresenter/KPrObject.h
+++ b/kpresenter/KPrObject.h
@@ -250,7 +250,7 @@ public:
* @return true if point lies in rect of object
* @return false otherwise
*/
- virtual bool tqcontains( const KoPoint &point ) const;
+ virtual bool contains( const KoPoint &point ) const;
/**
* @brief Check if rect intersects with rect of object
@@ -289,8 +289,8 @@ public:
/**
* Collect all textobjects.
* (KPrTextObject returns the object it tqcontains,
* a KPrGroupObject returns all the text objects it tqcontains)
*/
virtual void addTextObjects( TQPtrList<KoTextObject> & ) const {}
@@ -289,8 +289,8 @@ public:
/**
* Collect all textobjects.
- * (KPrTextObject returns the object it tqcontains,
- * a KPrGroupObject returns all the text objects it tqcontains)
+ * (KPrTextObject returns the object it contains,
+ * a KPrGroupObject returns all the text objects it contains)
*/
virtual void addTextObjects( TQPtrList<KoTextObject> & ) const {}